# Project Template for BHKLab Projects

## Project Overview

The BHKLab project template aims to provide:

- Simple project setup with pixi, mkdocs, and basic DMP folder structure
- Support for reproducible research with proper documentation
- GitHub integrations and standardized workflow
- Pre-configured `DMP-compliant` directories via [`damply`](https://github.com/bhklab/damply)

## How this works

This project uses the [copier tool](https://copier.readthedocs.io) to maintain
a standardized project template that follows the general structure of BHKLab
repositories.

Copier facilitates the management of project templates by
using [jinja2](https://jinja.palletsprojects.com/) templating for file/directory
names and content in the template.

## Issues

Please report any issues with the template to the
[bhklab/bhklab-project-template](https://github.com/bhklab/bhklab-project-template).

## Contributors

- Jermiah Joseph (@jjjermiah)
- Katy Scott (@strixy16)
